==> nextcloud-28.0.3.tgz: nextcloud/apps/logreader/l10n/tr.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Günlük kaydı",
    "Errors in the log" : "Günlükteki hatalar",
    "No errors in the logs since %s" : "%s zamanından beri günlükte bir hata yok",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%s zamanından beri günlükte %n hata var","%s zamanından beri günlükte %n hata var"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%s zamanından beri günlükte %n uyarı var","%s zamanından beri günlükte %n uyarı var"],
    "Log Reader" : "Günlük okuyucu",
    "A log reader for Nextcloud" : "Nextcloud günlük okuyucusu",
    "Log reader for Nextcloud" : "Nextcloud günlük okuyucusu",
    "Log reader" : "Günlük okuyucu",
    "Open log reader settings" : "Günlük okuyucu ayarlarını aç",
    "Log reader settings" : "Günlük okuyucu ayarları",
    "Currently the log file {file} is shown" : "Şu anda {file} günlük dosyası görüntüleniyor",
    "Show server log" : "Sunucu günlüğünü görüntüle",
    "Live view is disabled" : "Canlı görünüm devre dışı",
    "No log file" : "Herhangi bir günlük dosyası yok",
    "File-based logging must be enabled to access logs from the Web UI." : "İnternet kullanıcı arayüzünden günlüklere erişebilmek için dosya tabanlı günlük kaydı etkinleştirilmelidir.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Bir yanlışlık olduğunu düşünüyorsanız, lütfen {config} içinde {setting} ögesini doğrulayın ve Nextcloud yönetim rehberine bakın.",
    "Level" : "Düzey",
    "App" : "Uygulama",
    "No app in context" : "Bağlamda bir uygulama bulunamadı",
    "Time" : "Zaman",
    "Copy raw entry" : "Ham kaydı kopyala",
    "Copy formatted entry" : "Biçimlendirilmiş kaydı kopyala",
    "Hide exception details" : "Sorun ayrıntılarını gizle",
    "View exception details" : "Sorun ayrıntılarını görüntüle",
    "Raw log entry" : "Ham günlük kaydı",
    "Log entry successfully copied" : "Günlük kaydı kopyalandı",
    "Search log entries" : "Günlük kayıtlarını ara",
    "Caused by {exception}" : "{exception} nedeniyle",
    "Line {line}" : "{line}. satır",
    "Filter log levels" : "Günlük düzeylerini süz",
    "Set log level" : "Günlük kaydı düzeyini ayarla",
    "Time format" : "Saat biçimi",
    "Live view" : "Canlı görünüm",
    "Download/Upload logs" : "Günlüğü indir/yükle",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Ayrıca panonuzdan kopyalayacağınız günlük kayıtlarını, şu tuşları kullanarak günlük görünümüne yapıştırarak görüntüleyebilirsiniz: {keyboardShortcut}",
    "Download logs" : "Günlüğü indir",
    "Show local log file" : "Yerel günlük dosyasını görüntüle",
    "Upload local log file to be displayed" : "Görüntülenecek yerel günlük dosyasını yükleyin",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Yerel günlük dosyası işlenemedi",
    "Raw data" : "Ham veriler",
    "Local time" : "Yerel saat",
    "UTC time" : "UTC saati",
    "Time format used for displaying the timestamp" : "Zaman damgasının görüntüleneceği saat biçimi",
    "(Local log files only support the \"raw\" time format)" : "(Yerel günlük dosyaları yalnızca \"raw\" zaman biçimini destekler)",
    "Could not change date time format." : "Tarih ve saat biçimi değiştirilemedi.",
    "Polling is disabled because server is not configured to log to file" : "Toplama devre dışı çünkü sunucu günlüğü dosyaya kaydedecek şekilde yapılandırılmamış",
    "Polling (live view)" : "Toplama (canlı görünüm)",
    "Could not change live view setting." : "Canlı görünüm ayarları değiştirilemedi.",
    "Filter logging levels" : "Günlük düzeylerini süz",
    "Could not set logging levels to show" : "Görüntülenecek günlük düzeyleri ayarlanamadı",
    "Set backend loglevel" : "Yönetim bölümü günlük kaydı düzeyini ayarla",
    "Could not set logging level" : "Günlük kaydı düzeyi ayarlanamadı",
    "Application" : "Uygulama",
    "Message" : "İleti",
    "Log entry actions" : "Günlük kaydı işlemleri",
    "Loading older log entries" : "Daha eski günlük kayıtları yükleniyor",
    "No older log entries available" : "Daha eski bir günlük kaydı bulunamadı",
    "Collapse row" : "Satırı daralt",
    "Expand row" : "Satırı genişlet",
    "Show details" : "Ayrıntıları görüntüle",
    "Debug" : "Hata ayıklama",
    "Info" : "Bilgiler",
    "Warning" : "Uyarı",
    "Error" : "Hata",
    "Fatal" : "Kritik",
    "Could not load log entries" : "Günlük kayıtları yüklenemedi",
    "Clipboard" : "Pano",
    "Could not parse clipboard content" : "Pano içeriği işlenmesin",
    "Could not fetch new log entries (server unavailable)" : "Yeni günlük kayıtları alınamadı (sunucuya erişilemedi)",
    "Could not fetch new entries" : "Yeni kayıtlar alınamadı",
    "Could not copy to clipboard, please copy manually:" : "Panoya kopyalanamadı. Lütfen el ile kopyalayın:",
    "\tfrom {address} by {user} at {time}\n" : "\t{address} adresinden {user} tarafından {time} saatinde\n",
    "Error parsing log" : "Günlük işlenirken sorun çıktı",
    "Caused by " : "Nedeni",
    "Copy" : "Kopyala",
    "Copy raw" : "Ham olarak kopyala",
    "Copy formatted" : "Biçim ile kopyala",
    "No server logs" : "Herhangi bir sunucu günlüğü yok",
    "One or more entries are hidden by the log level filter" : "Bir ya da bir kaç kayıt günlük düzeyi süzgeci ile gizlenmiş",
    "Everything is working fine" : "Her şey sorunsuz çalışıyor",
    "Load log file" : "Günlük dosyasını yükle",
    "Invalid log file" : "Günlük dosyası geçersiz",
    "Log levels" : "Günlük düzeyleri",
    "Log content" : "Günlük içeriği",
    "Live update" : "Canlı güncelleme",
    "line {line}" : "{line}. satır",
    "Download / Upload logs" : "Günlüğü indir / yükle"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-29.0.12.tgz: nextcloud/apps/logreader/l10n/tr.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Günlük kaydı",
    "Errors in the log" : "Günlükteki hatalar",
    "Failed to get an iterator for log entries: %s" : "Günlük kayıtları için bir yineleyici alınamadı: %s",
    "No errors in the logs since %s" : "%s zamanından beri günlükte bir hata yok",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%s zamanından beri günlükte %n hata var","%s zamanından beri günlükte %n hata var"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%s zamanından beri günlükte %n uyarı var","%s zamanından beri günlükte %n uyarı var"],
    "Log Reader" : "Günlük okuyucu",
    "A log reader for Nextcloud" : "Nextcloud günlük okuyucusu",
    "Log reader for Nextcloud" : "Nextcloud günlük okuyucusu",
    "Log reader" : "Günlük okuyucu",
    "Open log reader settings" : "Günlük okuyucu ayarlarını aç",
    "Log reader settings" : "Günlük okuyucu ayarları",
    "Currently the log file {file} is shown" : "Şu anda {file} günlük dosyası görüntüleniyor",
    "Show server log" : "Sunucu günlüğünü görüntüle",
    "Live view is disabled" : "Canlı görünüm kapalı",
    "No log file" : "Herhangi bir günlük dosyası yok",
    "File-based logging must be enabled to access logs from the Web UI." : "İnternet kullanıcı arayüzünden günlüklere erişebilmek için dosya tabanlı günlük kaydı kullanıma alınmalıdır.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Bir yanlışlık olduğunu düşünüyorsanız, lütfen {config} içinde {setting} ögesini doğrulayın ve Nextcloud yönetim rehberine bakın.",
    "Level" : "Düzey",
    "App" : "Uygulama",
    "No app in context" : "Bağlamda bir uygulama bulunamadı",
    "Time" : "Zaman",
    "Copy raw entry" : "Ham kaydı kopyala",
    "Copy formatted entry" : "Biçimlendirilmiş kaydı kopyala",
    "Hide exception details" : "Sorun ayrıntılarını gizle",
    "View exception details" : "Sorun ayrıntılarını görüntüle",
    "Raw log entry" : "Ham günlük kaydı",
    "Log entry successfully copied" : "Günlük kaydı kopyalandı",
    "Search log entries" : "Günlük kayıtlarını ara",
    "Caused by {exception}" : "{exception} nedeniyle",
    "Line {line}" : "{line}. satır",
    "Filter log levels" : "Günlük düzeylerini süz",
    "Set log level" : "Günlük kaydı düzeyini ayarla",
    "Time format" : "Saat biçimi",
    "Live view" : "Canlı görünüm",
    "Download/Upload logs" : "Günlüğü indir/yükle",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Ayrıca panonuzdan kopyalayacağınız günlük kayıtlarını, şu tuşları kullanarak günlük görünümüne yapıştırarak görüntüleyebilirsiniz: {keyboardShortcut}",
    "Download logs" : "Günlüğü indir",
    "Show local log file" : "Yerel günlük dosyasını görüntüle",
    "Upload local log file to be displayed" : "Görüntülenecek yerel günlük dosyasını yükleyin",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Yerel günlük dosyası işlenemedi",
    "Raw data" : "Ham veriler",
    "Local time" : "Yerel saat",
    "UTC time" : "UTC saati",
    "Relative" : "Göreli",
    "Time format used for displaying the timestamp" : "Zaman damgasının görüntüleneceği saat biçimi",
    "(Local log files only support the \"raw\" time format)" : "(Yerel günlük dosyaları yalnızca \"raw\" zaman biçimini destekler)",
    "Could not change date time format." : "Tarih ve saat biçimi değiştirilemedi.",
    "Polling is disabled because server is not configured to log to file" : "Toplama kullanılmıyor çünkü sunucu günlüğü dosyaya kaydedecek şekilde yapılandırılmamış",
    "Polling (live view)" : "Toplama (canlı görünüm)",
    "Could not change live view setting." : "Canlı görünüm ayarları değiştirilemedi.",
    "Filter logging levels" : "Günlük düzeylerini süz",
    "Could not set logging levels to show" : "Görüntülenecek günlük düzeyleri ayarlanamadı",
    "Set backend loglevel" : "Yönetim bölümü günlük kaydı düzeyini ayarla",
    "Could not set logging level" : "Günlük kaydı düzeyi ayarlanamadı",
    "Application" : "Uygulama",
    "Message" : "İleti",
    "Log entry actions" : "Günlük kaydı işlemleri",
    "Loading older log entries" : "Daha eski günlük kayıtları yükleniyor",
    "No older log entries available" : "Daha eski bir günlük kaydı bulunamadı",
    "Collapse row" : "Satırı daralt",
    "Expand row" : "Satırı genişlet",
    "Show details" : "Ayrıntıları görüntüle",
    "Debug" : "Hata ayıklama",
    "Info" : "Bilgiler",
    "Warning" : "Uyarı",
    "Error" : "Hata",
    "Fatal" : "Kritik",
    "Could not load log entries" : "Günlük kayıtları yüklenemedi",
    "Clipboard" : "Pano",
    "Could not parse clipboard content" : "Pano içeriği işlenmesin",
    "Could not fetch new log entries (server unavailable)" : "Yeni günlük kayıtları alınamadı (sunucuya erişilemedi)",
    "Could not fetch new entries" : "Yeni kayıtlar alınamadı",
    "Could not copy to clipboard, please copy manually:" : "Panoya kopyalanamadı. Lütfen el ile kopyalayın:",
    "\tfrom {address} by {user} at {time}\n" : "\t{address} adresinden {user} tarafından {time} saatinde\n"
},
"nplurals=2; plural=(n > 1);");
